@@ -44,6 +44,7 @@ package KeyboardNames;
     'Chicony KB-9885' => 'chicony9885',
     'Chicony KU-0108' => 'chicony0108',
     'Chicony KU-0420' => 'chicony0420',
+    'Chromebook' => 'chromebook',
     'Classmate PC' => 'classmate',
     'Compaq Armada laptop' => 'armada',
     'Compaq Easy Access' => 'compaqeak8',
@@ -71,7 +72,7 @@ package KeyboardNames;
     'FL90' => 'compalfl90',
     'Fujitsu-Siemens Amilo laptop' => 'fscaa1667g',
     'Generic 101-key PC' => 'pc101',
-    'Generic 101-key PC (intl.)' => 'pc102',
+    'Generic 102-key PC (intl.)' => 'pc102',
     'Generic 104-key PC' => 'pc104',
     'Generic 105-key PC (intl.)' => 'pc105',
     'Genius Comfy KB-12e' => 'geniuscomfy',
@@ -181,6 +182,8 @@ package KeyboardNames;
     'Toshiba Satellite S3000' => 'toshiba_s3000',
     'Truly Ergonomic 227' => 'teck227',
     'Truly Ergonomic 229' => 'teck229',
+    'Truly Ergonomic Computer Keyboard Model 227 (Wide Alt keys)' => 'teck227',
+    'Truly Ergonomic Computer Keyboard Model 229 (Standard sized Alt keys, additional Super and Menu key)' => 'teck229',
     'Trust Direct Access' => 'trustda',
     'Trust Slimline' => 'trust_slimline',
     'Trust Wireless Classic' => 'trust',
@@ -364,7 +367,9 @@ package KeyboardNames;
 	'Portuguese (Brazil, no dead keys)' => 'nodeadkeys',
     },
     'brai' => {
+	'Braille (left-handed inverted thumb)' => 'left_hand_invert',
 	'Braille (left-handed)' => 'left_hand',
+	'Braille (right-handed inverted thumb)' => 'right_hand_invert',
 	'Braille (right-handed)' => 'right_hand',
     },
     'by' => {
@@ -398,6 +403,7 @@ package KeyboardNames;
 	'Mmuock' => 'mmuock',
     },
     'cn' => {
+	'Hanyu Pinyin (altgr)' => 'altgr-pinyin',
 	'Tibetan' => 'tib',
 	'Tibetan (with ASCII numerals)' => 'tib_asciinum',
 	'Uyghur' => 'ug',
@@ -475,6 +481,7 @@ package KeyboardNames;
 	'French (Breton)' => 'bre',
 	'French (Dvorak)' => 'dvorak',
 	'French (Macintosh)' => 'mac',
+	'French (US, with French letters)' => 'us',
 	'French (alt.)' => 'oss',
 	'French (alt., Latin-9 only)' => 'oss_latin9',
 	'French (alt., no dead keys)' => 'oss_nodeadkeys',
@@ -495,6 +502,7 @@ package KeyboardNames;
 	'English (UK, extended, with Win keys)' => 'extd',
 	'English (UK, intl., Macintosh)' => 'mac_intl',
 	'English (UK, intl., with dead keys)' => 'intl',
+	'Polish (British keyboard)' => 'pl',
     },
     'ge' => {
 	'Georgian (MESS)' => 'mess',
@@ -580,11 +588,11 @@ package KeyboardNames;
 	'Punjabi (Gurmukhi Jhelum)' => 'jhelum',
 	'Punjabi (Gurmukhi)' => 'guru',
 	'Sanskrit (KaGaPa phonetic)' => 'san-kagapa',
-	'Tamil' => 'tam',
-	'Tamil (TAB typewriter)' => 'tam_TAB',
-	'Tamil (TSCII typewriter)' => 'tam_TSCII',
-	'Tamil (Unicode)' => 'tam_unicode',
-	'Tamil (keyboard with numerals)' => 'tam_keyboard_with_numerals',
+	'Tamil (Inscript)' => 'tam',
+	'Tamil (TamilNet 99 with Tamil numerals)' => 'tam_tamilnet_with_tam_nums',
+	'Tamil (TamilNet 99)' => 'tam_tamilnet',
+	'Tamil (TamilNet 99, TAB encoding)' => 'tam_tamilnet_TAB',
+	'Tamil (TamilNet 99, TSCII encoding)' => 'tam_tamilnet_TSCII',
 	'Telugu' => 'tel',
 	'Telugu (KaGaPa phonetic)' => 'tel-kagapa',
 	'Telugu (Sarala)' => 'tel-sarala',
@@ -639,6 +647,7 @@ package KeyboardNames;
 	'Korean (101/104 key compatible)' => 'kr104',
     },
     'kz' => {
+	'Kazakh (Latin)' => 'latin',
 	'Kazakh (extended)' => 'ext',
 	'Kazakh (with Russian)' => 'kazrus',
 	'Russian (Kazakhstan, with Kazakh)' => 'ruskaz',
@@ -647,6 +656,8 @@ package KeyboardNames;
 	'Lao (STEA proposed standard layout)' => 'stea',
     },
     'latam' => {
+	'Spanish (Latin American, Colemak for gaming)' => 'colemak-gaming',
+	'Spanish (Latin American, Colemak)' => 'colemak',
 	'Spanish (Latin American, Dvorak)' => 'dvorak',
 	'Spanish (Latin American, dead tilde)' => 'deadtilde',
 	'Spanish (Latin American, no dead keys)' => 'nodeadkeys',
@@ -654,8 +665,8 @@ package KeyboardNames;
     },
     'lk' => {
 	'Sinhala (US, with Sinhala letters)' => 'us',
-	'Tamil (Sri Lanka, TAB Typewriter)' => 'tam_TAB',
-	'Tamil (Sri Lanka, Unicode)' => 'tam_unicode',
+	'Tamil (Sri Lanka, TamilNet 99)' => 'tam_unicode',
+	'Tamil (Sri Lanka, TamilNet 99, TAB encoding)' => 'tam_TAB',
     },
     'lt' => {
 	'Lithuanian (IBM LST 1205-92)' => 'ibm',
@@ -701,6 +712,9 @@ package KeyboardNames;
 	'English (Mali, US, intl.)' => 'us-intl',
 	'French (Mali, alt.)' => 'fr-oss',
     },
+    'mm' => {
+	'Burmese Zawgyi' => 'zawgyi',
+    },
     'mt' => {
 	'Maltese (with US layout)' => 'us',
     },
@@ -793,6 +807,7 @@ package KeyboardNames;
 	'Russian (DOS)' => 'dos',
 	'Russian (Macintosh)' => 'mac',
 	'Russian (legacy)' => 'legacy',
+	'Russian (phonetic yazherty)' => 'phonetic_yazherty',
 	'Russian (phonetic)' => 'phonetic',
 	'Russian (phonetic, AZERTY)' => 'phonetic_azerty',
 	'Russian (phonetic, Dvorak)' => 'phonetic_dvorak',
@@ -812,6 +827,7 @@ package KeyboardNames;
 	'Swedish (Dvorak)' => 'dvorak',
 	'Swedish (Macintosh)' => 'mac',
 	'Swedish (Svdvorak)' => 'svdvorak',
+	'Swedish (US, with Swedish letters)' => 'us',
 	'Swedish (based on US Intl. Dvorak)' => 'us_dvorak',
 	'Swedish (no dead keys)' => 'nodeadkeys',
 	'Swedish Sign Language' => 'swl',
@@ -891,6 +907,10 @@ package KeyboardNames;
     'uz' => {
 	'Uzbek (Latin)' => 'latin',
     },
+    'vn' => {
+	'Vietnamese (French, with Vietnamese letters)' => 'fr',
+	'Vietnamese (US, with Vietnamese letters)' => 'us',
+    },
 );
 
 1;
